<template>
  <div class="zqlfx">
    <div class="title">准确率分析</div>
    <div class="chart">
      <div class="chartLeft" ref="chartLeftRef">
        <div class="value">{{ syResult }}%</div>
        <div class="text">溯源准确率</div>
      </div>
      <div class="chartRight" ref="chartRightRef">
        <div class="value">{{ ycResult }}%</div>
        <div class="text">预测准确率</div>
      </div>
    </div>
  </div>
</template>

<script setup>
import * as echarts from "echarts"
import { ref, onMounted, reactive } from "vue"
import { querySuYuanStatic, querySevenAccuracyStatic } from "@/api/api.js"

const chartLeftRef = ref(null)
const chartRightRef = ref(null)

onMounted(() => {
  // initChart(chartLeftRef.value)
  // initChart(chartRightRef.value)
  // getSy()
  // getYc()
  //获取准确率分析数据
  getAccuracyData();
})

const syResult = ref(0)
const ycResult = ref(92)

//获取准确率分析数据
async function getAccuracyData(){
  const res = await querySevenAccuracyStatic()
  if (res.code == 200) {
    syResult.value = res.result.practicalRate
    ycResult.value = res.result.forecastRate
  }
}
async function getSy() {
  const res = await querySuYuanStatic()
  if (res.code == 200) {
    syResult.value = res.result * 100
  }
}

async function getYc() {
  const res = await querySevenAccuracyStatic()
  if (res.code == 200) {
    ycResult.value = res.result * 100
  }
}

function initChart(dom) {
  let myChart = echarts.init(dom)

  var dataArr = [
    {
      value: 91,
      name: "综合健康评分",
    },
  ]
  var color = new echarts.graphic.LinearGradient(0, 0, 1, 0, [
    {
      offset: 0,
      color: "#5CF9FE", // 0% 处的颜色
    },
    {
      offset: 0.17,
      color: "#468EFD", // 100% 处的颜色
    },
    {
      offset: 0.9,
      color: "#468EFD", // 100% 处的颜色
    },
    {
      offset: 1,
      color: "#5CF9FE", // 100% 处的颜色
    },
  ])
  var colorSet = [
    [0.91, color],
    [1, "#15337C"],
  ]
  var rich = {
    white: {
      fontSize: 20,
      color: "#fff",
      fontWeight: "500",
      padding: [0, 0, 0, 0],
    },
    bule: {
      fontSize: 20,
      fontFamily: "DINBold",
      color: "#fff",
      fontWeight: "700",
      padding: [0, 0, 0, 0],
    },
  }
  let option = {
    backgroundColor: "#0E1327",
    tooltip: {
      formatter: "{a} <br/>{b} : {c}%",
    },
    grid: {
      top: 0,
      bottom: 0,
    },

    series: [
      {
        //内圆
        type: "pie",
        radius: "95%",
        // center: ["-50%", "50%"],
        z: 0,
        itemStyle: {
          normal: {
            color: new echarts.graphic.RadialGradient(
              0.5,
              0.5,
              1,
              [
                {
                  offset: 0,
                  color: "rgba(17,24,43,0)",
                },
                {
                  offset: 0.5,
                  // color: '#1E2B57'
                  color: "rgba(28,42,91,.6)",
                },
                {
                  offset: 1,
                  color: "#141C33",
                  // color:'rgba(17,24,43,0)'
                },
              ],
              false
            ),
            label: {
              show: false,
            },
            labelLine: {
              show: false,
            },
          },
        },
        hoverAnimation: false,
        label: {
          show: false,
        },
        tooltip: {
          show: false,
        },
        data: [100],
      },
      {
        type: "gauge",
        name: "外层辅助",
        radius: "88%",
        startAngle: "225",
        endAngle: "-45",
        splitNumber: "100",
        pointer: {
          show: false,
        },
        detail: {
          show: false,
        },
        data: [
          {
            value: 1,
          },
        ],
        // data: [{value: 1, name: 90}],
        title: {
          show: true,
          offsetCenter: [0, 10],
          textStyle: {
            color: "#fff",
            fontStyle: "normal",
            fontWeight: "normal",
            fontFamily: "微软雅黑",
            fontSize: 20,
          },
        },
        axisLine: {
          show: true,
          lineStyle: {
            color: [[1, "#00FFFF"]],
            width: 2,
            opacity: 1,
          },
        },
        axisTick: {
          show: false,
        },
        splitLine: {
          show: true,
          length: 2,
          lineStyle: {
            color: "#051932",
            width: 0,
            type: "solid",
          },
        },
        axisLabel: {
          show: false,
        },
      },
      {
        type: "gauge",
        radius: "85%",
        startAngle: "225",
        endAngle: "-45",
        pointer: {
          show: false,
        },
        detail: {
          formatter: function (value) {
            var num = Math.round(value)
            return "{bule|" + num + "}{white|分}"
          },
          rich: rich,
          offsetCenter: ["0%", "0%"],
        },
        data: dataArr,
        title: {
          show: false,
        },
        axisLine: {
          show: true,
          lineStyle: {
            color: colorSet,
            width: 20,
            // shadowBlur: 15,
            // shadowColor: '#B0C4DE',
            shadowOffsetX: 0,
            shadowOffsetY: 0,
            opacity: 1,
          },
        },
        axisTick: {
          show: false,
        },
        splitLine: {
          show: false,
          length: 10,
          lineStyle: {
            color: "#00377a",
            width: 2,
            type: "solid",
          },
        },
        axisLabel: {
          show: false,
        },
      },
      {
        name: "灰色内圈", //刻度背景
        type: "gauge",
        z: 2,
        radius: "78%",
        startAngle: "225",
        endAngle: "-45",
        //center: ["50%", "75%"], //整体的位置设置
        axisLine: {
          // 坐标轴线
          lineStyle: {
            // 属性lineStyle控制线条样式
            color: [[1, "#018DFF"]],
            width: 3,
            opacity: 1, //刻度背景宽度
          },
        },
        splitLine: {
          show: false,
        },
        // data: [{
        //     show: false,
        //     value: '80'
        // }], //作用不清楚
        axisLabel: {
          show: false,
        },
        pointer: {
          show: false,
        },
        axisTick: {
          show: false,
        },
        detail: {
          show: 0,
        },
      },
      // {
      //   name: "白色圈刻度",
      //   type: "gauge",
      //   radius: "94%",
      //   startAngle: 225, //刻度起始
      //   endAngle: -45, //刻度结束
      //   z: 4,
      //   axisTick: {
      //     show: false,
      //   },
      //   splitLine: {
      //     length: 16, //刻度节点线长度
      //     lineStyle: {
      //       width: 2,
      //       color: "rgba(1,244,255, 0.9)",
      //     }, //刻度节点线
      //   },
      //   axisLabel: {
      //     color: "rgba(255,255,255,0)",
      //     fontSize: 12,
      //   }, //刻度节点文字颜色
      //   pointer: {
      //     show: false,
      //   },
      //   axisLine: {
      //     lineStyle: {
      //       opacity: 0,
      //     },
      //   },
      //   detail: {
      //     show: false,
      //   },
      //   data: [
      //     {
      //       value: 0,
      //       name: "",
      //     },
      //   ],
      // },
      {
        //内圆
        type: "pie",
        radius: "80%",
        center: ["50%", "50%"],
        z: 1,
        itemStyle: {
          normal: {
            color: new echarts.graphic.RadialGradient(
              0.5,
              0.5,
              0.8,
              [
                {
                  offset: 0,
                  color: "#4978EC",
                },
                {
                  offset: 0.5,
                  color: "#1E2B57",
                },
                {
                  offset: 1,
                  color: "#141F3D",
                },
              ],
              false
            ),
            label: {
              show: false,
            },
            labelLine: {
              show: false,
            },
          },
        },
        hoverAnimation: false,
        label: {
          show: false,
        },
        tooltip: {
          show: false,
        },
        data: [100],
      },
    ],
  }

  myChart.setOption(option)
  window.onresize = function () {
    //自适应大小
    myChart.resize()
  }
}
</script>

<style lang="less" scoped>
.zqlfx {
  position: absolute;
  top: 1215px;
  left: 27px;
  width: 742px;
  height: 299px;
  background: url("~@/assets/img/xgzs/gjfx.png");
  background-size: 100% 100%;
  box-sizing: border-box;
  .title {
    padding: 40px;
    font-size: 30px;
    font-weight: bold;
    color: #ffffff;
    padding-bottom: 10px;
  }
  .chart {
    display: flex;
    justify-content: space-evenly;
    width: 100%;
    height: 200px;
  }
  .chartLeft,
  .chartRight {
    position: relative;
    width: 150px;
    height: 150px;
    background: url("~@/assets/img/xgzs/仪表盘.png");
    background-size: 100% 100%;
    .value {
      position: absolute;
      top: 50%;
      left: 50%;
      transform: translate(-50%, -50%);
      font-size: 20px;
      font-family: AliHYAiHei;
      font-weight: 400;
      color: #ffffff;
    }
    .text {
      width: 100%;
      position: absolute;
      bottom: -30px;
      font-size: 24px;
      font-family: Source Han Sans CN;
      font-weight: 400;
      color: #ffffff;
      text-align: center;
    }
  }
}
</style>
